/**
 * File customizer.js.
 * Theme Customizer enhancements for a better user experience.
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	
$head = $('head');
	
	"use strict";

	let root = document.documentElement;
	
		
	// functions for our customer show or hide settings
	function hideElement( element ) {
		$( element ).css({
			clip: 'rect(1px, 1px, 1px, 1px)',
			position: 'absolute',
			width: '1px',
			height: '1px',
			overflow: 'hidden'
		});
	}

	function showElement( element ) {
		$( element ).css({
			clip: 'auto',
			position: 'relative',
			width: 'auto',
			height: 'auto',
			overflow: 'visible'
		});
	}
	
	// To show absolute positioned elements
	function showAbElement( element ) {
		$( element ).css({
			clip: 'auto',
			position: 'absolute',
			width: 'auto',
			height: 'auto',
			overflow: 'visible'
		});
	}
	
/* IMAGE HEIGHT PREVIEWS
 ======================= */	
	// hero min page size
	wp.customize( 'serifi_showcase_image_height', function( value ) {
		value.bind( function( to ) {
			var style = $('#page-showcase-image-css');
			style.remove();
			style = $( '<style type="text/css" id="#page-showcase-image-css"> #showcase-image { min-height: ' + to + 'px; } </style>' ).appendTo( $head );
		} );
	} );
	
/* FONT PREVIEWS
 ======================= */

	// Site title font
	wp.customize( 'site_title_font', function( value ) {
		value.bind( function( to ) {
			var style = $('#site-title-font-css');
			style.remove();
			style = $( '<style type="text/css" id="site-title-font-css"> #site-title { --serifi-font-secondary:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	// Site title size
	wp.customize( 'site_title_font_size', function( value ) {
		value.bind( function( to ) {
			var style = $('#site-title-size-css');
			style.remove();
			style = $( '<style type="text/css" id="site-title-size-css"> #site-title a { font-size: calc(1rem + ' + to + 'vw) } </style>' ).appendTo( $head );
		} );
	} );

	// Site font size
	wp.customize( 'serifi_font_size', function( value ) {
		value.bind( function( to ) {
			var style = $('#serifi-font-size-css');
			style.remove();
			style = $( '<style type="text/css" id="serifi-font-size-css"> html { font-size: calc(' + to + 'px + 0.025vw) } </style>' ).appendTo( $head );
		} );
	} );
	
/* TEXT PREVIEWS
 ======================= */
 	// Site title.	
	wp.customize( 'blogname', function( value ) {
	  value.bind( function( newval ) {
		$( '#site-title' ).html( newval );
	  } );
	} );
	
	// Site description.	
	wp.customize( 'blogdescription', function( value ) {
	  value.bind( function( newval ) {
		$( '#site-description' ).html( newval );
	  } );
	} );
		
	// Copyright
	wp.customize( 'serifi_copyright', function( value ) {
	  value.bind( function( newval ) {
		$( '#copyright-name' ).html( newval );
	  } );
	} );

/* SHOW or HIDE
======================= */
	
	// Hide site title
	wp.customize( 'serifi_show_site_title', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				hideElement( '#site-title' );
			} else {
				showElement( '#site-title' );
			}
		} );
	} );
	
	// Hide site tagline
	wp.customize( 'serifi_show_site_desc', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				hideElement( '#site-description' );
			} else {
				showElement( '#site-description' );
			}
		} );
	} );	

	// Hide header search icon
	wp.customize( 'serifi_hide_header_search', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showAbElement( '#search-toggle' );
			} else {
				hideElement( '#search-toggle' );
			}
		} );
	} );
	
	// Hide edit link
	wp.customize( 'serifi_hide_edit', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.edit-link' );
			} else {
				hideElement( '.edit-link' );
			}
		} );
	} );
	
	// Hide archiver prefix
	wp.customize( 'serifi_hide_prefix_archive', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.archive-prefix' );
			} else {
				hideElement( '.archive-prefix' );
			}
		} );
	} );	

	// Hide post author bio
	wp.customize( 'serifi_hide_author_bio', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.author-info' );
			} else {
				hideElement( '.author-info' );
			}
		} );
	} );
	
	// Hide post footer
	wp.customize( 'serifi_hide_post_footer', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.entry-footer' );
			} else {
				hideElement( '.entry-footer' );
			}
		} );
	} );

	
/* COLOURS
======================= */

	// Primary Colour
	wp.customize( 'serifi_custom_primary_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-colour-primary', to );
		} );
	} );

	// Secondary Colour
	wp.customize( 'serifi_custom_secondary_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-colour-secondary', to );
		} );
	} );

	// Tertiary Colour
	wp.customize( 'serifi_custom_tertiary_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-colour-secondary', to );
		} );
	} );




	// Site title colour
	wp.customize( 'serifi_header_title_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-colour-sitetitle', to );
		} );
	} );
	
	// Site description (tagline) colour
	wp.customize( 'serifi_tagline_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-tagline-colour', to );
		} );
	} );	
	
	// Body bg
	wp.customize( 'serifi_body_bg_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-body-bg-colour', to );
		} );
	} );	

	// Content bg
	wp.customize( 'serifi_content_bg_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-content-bg-colour', to );
		} );
	} );	
	

	// Select text bg
	wp.customize( 'serifi_select_text_bg_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-select-text-bg-colour', to );
		} );
	} );

	// Select text
	wp.customize( 'serifi_select_text_colour', function( value ) {
		value.bind( function( to ) {
			root.style.setProperty('--serifi-select-text-colour', to );
		} );
	} );


	
} )( jQuery );
