<?php

/**
 * Functions and definitions
 * @package serifi
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

// This theme requires WordPress 5.3 or later.
if (version_compare($GLOBALS['wp_version'], '5.3', '<')) {
	require get_template_directory() . '/inc/back-compat.php';
}

/* THEME SETUP
   ==================================================== */
// Sets up theme defaults and registers support for various WordPress features.
if (!function_exists('serifi_setup')) {
	function serifi_setup()
	{

		// Theme text domain
		load_theme_textdomain('serifi', get_template_directory() . '/languages');

		// Add theme support for various features.
		add_theme_support('automatic-feed-links');
		add_theme_support('title-tag');
		add_theme_support('post-thumbnails');
		add_theme_support('customize-selective-refresh-widgets');
		add_theme_support('align-wide');
		add_theme_support('wp-block-styles');
		add_theme_support('responsive-embeds');
		add_theme_support('custom-line-height');
		add_theme_support('experimental-link-color');
		add_theme_support('custom-spacing');
		add_theme_support('custom-units');
		add_theme_support('editor-styles');

		// Editor style path
		$editor_stylesheet_path = './assets/css/style-editor.css';
		add_editor_style(array($editor_stylesheet_path));

		add_theme_support('html5',	array(
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
				'navigation-widgets',
			)
		);

		add_theme_support('custom-logo', array(
				'height' => 100,
				'width' => 300,
				'flex-width' => true,
				'flex-height' => true,
				'unlink-homepage-logo' => true,
			)
		);

		// Add Page Excerpt support
		add_post_type_support('page', 'excerpt');

		// Thumbnail sizes
		set_post_thumbnail_size(1100, 9999);
		add_image_size('serifi-thumbnail', 70, 70, true);

		// Register primary menu.
		register_nav_menus(
			array(
				'primary' => esc_html__('Primary menu', 'serifi'),
				'footer'  => esc_html__('Footer menu', 'serifi'),
				'footer-social'  => esc_html__('Social menu', 'serifi'),
			)
		);

		// Custom backgrounds.
		add_theme_support( 'custom-background', array(
				'default-color' => 'dfe1df',
			)
		);

		// Add custom editor font sizes.
		add_theme_support( 'editor-font-sizes', array(
				array(
					'name'      => esc_html__('Extra small', 'serifi'),
					'shortName' => esc_html_x('XS', 'Font size', 'serifi'),
					'size'      => 14,
					'slug'      => 'extra-small',
				),
				array(
					'name'      => esc_html__('Small', 'serifi'),
					'shortName' => esc_html_x('S', 'Font size', 'serifi'),
					'size'      => 16,
					'slug'      => 'small',
				),
				array(
					'name'      => esc_html__('Normal', 'serifi'),
					'shortName' => esc_html_x('M', 'Font size', 'serifi'),
					'size'      => 18,
					'slug'      => 'normal',
				),
				array(
					'name'      => esc_html__('Large', 'serifi'),
					'shortName' => esc_html_x('L', 'Font size', 'serifi'),
					'size'      => 24,
					'slug'      => 'large',
				),
				array(
					'name'      => esc_html__('Extra large', 'serifi'),
					'shortName' => esc_html_x('XL', 'Font size', 'serifi'),
					'size'      => 34,
					'slug'      => 'extra-large',
				),
				array(
					'name'      => esc_html__('Huge', 'serifi'),
					'shortName' => esc_html_x('XXL', 'Font size', 'serifi'),
					'size'      => 48,
					'slug'      => 'huge',
				),
				array(
					'name'      => esc_html__('Gigantic', 'serifi'),
					'shortName' => esc_html_x('XXXL', 'Font size', 'serifi'),
					'size'      => 60,
					'slug'      => 'gigantic',
				),
			)
		);

		// Editor color palette.
		$black      = '#000';
		$dark_grey     = '#404040';
		$grey     = '#808080';
		$light_grey      = '#bfbfbf';
		$white     = '#ffffff';
		$primary = esc_attr(get_theme_mod('serifi_custom_primary_colour', '#818f9e'));
		$secondary    = esc_attr(get_theme_mod('serifi_custom_secondary_colour', '#a6924a'));
		$tertiary = esc_attr(get_theme_mod('serifi_custom_tertiary_colour', '#2d283f'));

		add_theme_support(
			'editor-color-palette',
			array(
				array(
					'name'  => esc_html__('Black', 'serifi'),
					'slug'  => 'black',
					'color' => $black,
				),
				array(
					'name'  => esc_html__('Dark grey', 'serifi'),
					'slug'  => 'dark-grey',
					'color' => $dark_grey,
				),

				array(
					'name'  => esc_html__('Grey', 'serifi'),
					'slug'  => 'grey',
					'color' => $grey,
				),

				array(
					'name'  => esc_html__('Light grey', 'serifi'),
					'slug'  => 'light-grey',
					'color' => $light_grey,
				),

				array(
					'name'  => esc_html__('White', 'serifi'),
					'slug'  => 'white',
					'color' => $white,
				),

				// Accent colours - Primary is blue, Secondary is yellow, Tertiary is purple
				array(
					'name'  => esc_html__('Primary', 'serifi'),
					'slug'  => 'primary',
					'color' => $primary,
				),
				array(
					'name'  => esc_html__('Secondary', 'serifi'),
					'slug'  => 'secondary',
					'color' => $secondary,
				),
				array(
					'name'  => esc_html__('Tertiary', 'serifi'),
					'slug'  => 'tertiary',
					'color' => $tertiary,
				),

			)
		);

		add_theme_support(
			'editor-gradient-presets',
			array(
				array(
					'name'     => esc_html__('Primary to Tertiary', 'serifi'),
					'gradient' => 'linear-gradient(90deg, ' . $tertiary . ' 0%, ' . $primary . ' 100%)',
					'slug'     => 'primary-to-tertiary',
				),
				array(
					'name'     => esc_html__('Black to Tertiary', 'serifi'),
					'gradient' => 'linear-gradient(90deg, ' . $black . ' 0%, ' . $tertiary . ' 100%)',
					'slug'     => 'black-to-tertiary',
				),
				array(
					'name'     => esc_html__('Primary to White', 'serifi'),
					'gradient' => 'linear-gradient(90deg, ' . $primary . ' 0%, ' . $white . ' 100%)',
					'slug'     => 'primary-to-white',
				),
				array(
					'name'     => esc_html__('Secondary to White', 'serifi'),
					'gradient' => 'linear-gradient(90deg, ' . $secondary . ' 0%, ' . $white . ' 100%)',
					'slug'     => 'secondary-to-white',
				),
				array(
					'name'     => esc_html__('Black to Grey', 'serifi'),
					'gradient' => 'linear-gradient(90deg, ' . $black . ' 0%, ' . $grey . ' 100%)',
					'slug'     => 'black-to-grey',
				),
				array(
					'name'     => esc_html__('Dark Grey to Grey', 'serifi'),
					'gradient' => 'linear-gradient(90deg, ' . $dark_grey . ' 0%, ' . $grey . ' 100%)',
					'slug'     => 'dark-grey-to-grey',
				),
				array(
					'name'     => esc_html__('Grey to Light Grey', 'serifi'),
					'gradient' => 'linear-gradient(90deg, ' . $grey . ' 0%, ' . $light_grey . ' 100%)',
					'slug'     => 'grey-to-light-grey',
				),
			)
		);
	}
}
add_action('after_setup_theme', 'serifi_setup');


/* SET CONTENT WIDTH
   ==================================================== */
$GLOBALS['content_width'] = 1200;

function serifi_content_width()
{
	$content_width = $GLOBALS['content_width'];
	// Check if the page has a sidebar.
	if (is_active_sidebar('left-sidebar') || is_active_sidebar('right-sidebar') || is_active_sidebar('blog-sidebar')) {
		$content_width = 800;
	}
	$GLOBALS['content_width'] = apply_filters('serifi_content_width', $content_width);
}
add_action('template_redirect', 'serifi_content_width', 0);


/* SKIP LINK FOCUS
   ====================================================*/
function serifi_skip_link_focus_fix()
{

	// If SCRIPT_DEBUG is defined and true, print the unminified file.
	if (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) {
		echo '<script>';
		include get_template_directory() . '/assets/js/skip-link-focus-fix.js';
		echo '</script>';
	}
?>
	<script>
		/(trident|msie)/i.test(navigator.userAgent) && document.getElementById && window.addEventListener && window.addEventListener("hashchange", (function() {
			var t, e = location.hash.substring(1);
			/^[A-z0-9_-]+$/.test(e) && (t = document.getElementById(e)) && (/^(?:a|select|input|button|textarea)$/i.test(t.tagName) || (t.tabIndex = -1), t.focus())
		}), !1);
	</script>
<?php
}
add_action('wp_print_footer_scripts', 'serifi_skip_link_focus_fix');



/* REGISTER STYLESHEETS
   ==================================================== */
if (!function_exists('serifi_register_styles')) :
	function serifi_register_styles(){

		// Bootstrap Icons
		wp_enqueue_style('bootstrap-icons', get_template_directory_uri() . '/assets/css/bootstrap-icons.css', array(), null);

		// Block styles - Front-end
		if (false == esc_attr(get_theme_mod('serifi_block_css', false))) {
			wp_enqueue_style('block-styles-css', get_template_directory_uri() . '/assets/css/block-styles.css', array(), null);
		}


		// Bootstrap styles
		wp_enqueue_style('bootstrap-reboot', get_template_directory_uri() . '/assets/css/bootstrap-reboot.css', array(), null);
		wp_enqueue_style('bootstrap-grid', get_template_directory_uri() . '/assets/css/bootstrap-grid.css', array(), null);

		$theme_version = wp_get_theme()->get('Version');
		$css_dependencies = array();


		// Load our theme stylesheet
		wp_enqueue_style('serifi-style', get_template_directory_uri() . '/style.css', $css_dependencies, $theme_version);
	}

endif;
add_action('wp_enqueue_scripts', 'serifi_register_styles');


/* REGISTER SCRIPTS
   ==================================================== */
if (!function_exists('serifi_register_scripts')) :
	function serifi_register_scripts()
	{

		// Version
		$theme_version = wp_get_theme('serifi')->get('Version');

		// Built-in JS assets
		$js_dependencies = array('jquery');

		// Filter the list of dependencies used  with JavaScript enqueues
		$js_dependencies = apply_filters('serifi_lite_js_dependencies', $js_dependencies);

		// Skip to link
		wp_enqueue_script('serifi-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), null, true);

		// Theme scripts
		$js_dependencies = array('jquery');
		wp_enqueue_script('serifi-scripts', get_template_directory_uri() . '/assets/js/theme-scripts.js', $js_dependencies, $theme_version, true);

		// Check Comments
		if ((!is_admin()) && is_singular() && comments_open() && get_option('thread_comments')) {
			wp_enqueue_script('comment-reply');
		}
	}
	add_action('wp_enqueue_scripts', 'serifi_register_scripts');
endif;


/* EDITOR STYLES FOR THE BLOCK EDITOR
   ==================================================== */
if (!function_exists('serifi_block_editor_styles')) :
	function serifi_block_editor_styles()
	{

		$css_dependencies = array();

		wp_enqueue_style('serifi-block-editor-style', get_template_directory_uri() . '/assets/css/style-editor.css', array(), '20190905');
	}
	add_action('enqueue_block_editor_assets', 'serifi_block_editor_styles', 10);

endif;


/* EDITOR STYLES FOR THE CLASSIC EDITOR
   ==================================================== */
if (!function_exists('serifi_classic_editor_styles')) :
	function serifi_classic_editor_styles()	{
		$classic_editor_styles = array(
			'/assets/css/style-editor-classic.css',
		);
		add_editor_style($classic_editor_styles);
	}
	add_action('init', 'serifi_classic_editor_styles');

endif;


/* INCLUDES - ADDITIONAL FUNCTIONS & CLASSES
   ==================================================== */

// Function files
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';
require get_template_directory() . '/inc/sidebars.php';
require get_template_directory() . '/inc/inline-styles.php';

// Customizer
require get_template_directory() . '/inc/customizer/custom-controls/custom-control.php';
require get_template_directory() . '/inc/customizer/customizer.php';

// Load theme structure
require get_template_directory() . '/inc/layouts/header-layouts.php';
require get_template_directory() . '/inc/layouts/blog-layouts.php';
require get_template_directory() . '/inc/layouts/post-layouts.php';
