<?php
/**
 * The header for our theme
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 * @package Serifi
 * @since 1.0.4
 */
 
 if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

$header_layout = esc_attr(get_theme_mod( 'serifi_header_layout', 'header1' ));
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>" />
	<meta name="viewport" content="width=device-width, initial-scale=1" />
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php if ( function_exists( 'wp_body_open' ) ) {
		wp_body_open(); 
		}
	?>

	<?php // Load our branding if header style 3 is active
	if ( $header_layout === 'header3') {
	serifi_header_branding(); 
	}
	?>

	<?php // Action hook for any content placed before the page wrapper
	do_action ( 'serifi_before_page' );
	?>
		
	<div id="page" class="site">
	
		<?php // load our announcement sidebar
		get_template_part( 'template-parts/sidebar', 'announcement' ); ?>
		
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'serifi' ); ?></a>
	
<?php get_template_part( 'template-parts/modal-search' ); ?>
	
		<div id="hero">
			<?php // Load our header layout in the hero wrapper
			serifi_header_layout(); 
			
			// Action hook for the inside of the hero wrapper
			do_action ( 'serifi_inside_hero' );
			?>			
		</div>
		
	<?php
		// Action hook before the banner sidebar
		do_action ( 'serifi_before_banner' );
		
		// Load our banner sidebar
		get_template_part( 'template-parts/sidebar', 'banner' ); 
	
		// Action hook after the banner sidebar
		do_action ( 'serifi_after_banner' );
	?>
			
	<div id="content" class="site-content">
		<main id="main" class="site-main">	