<?php
/**
 * Blog Settings
 * @package Serifi
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if( ! function_exists( 'serifi_customize_register_blog' ) ) :
function serifi_customize_register_blog( $wp_customize ) {
    
    /** Blog Options */
    $wp_customize->add_section( 'serifi_blog_options', array(
            'title'    => esc_html__( 'Blog Options', 'serifi' ),
            'priority' => 22,
        )
    );
    	
	// Heading - blog excerpts
	$wp_customize->add_control( new Serifi_Note_Control(
		$wp_customize, 'serifi_blog_excerpts_note', array(
			'label' => esc_html__( 'Blog Excerpts', 'serifi' ),
			'section' => 'serifi_blog_options',
			 'priority' => 2,
			'settings' => array(),
			)
	) );
	
    /** Blog Excerpt */
    $wp_customize->add_setting( 'serifi_blog_excerpt', array(
            'default'           => 1,
            'sanitize_callback' => 'serifi_sanitize_checkbox',
        ) 
    );
    
    $wp_customize->add_control( new Serifi_Toggle_Control( $wp_customize, 'serifi_blog_excerpt',	array(
				'section'     => 'serifi_blog_options',
				'priority' => 2,
				'label'	      => esc_html__( 'Enable Blog Excerpts', 'serifi' ),
                'description' => esc_html__( 'Enable to show excerpts or disable to show full post content.', 'serifi' ),
			)
		)
	);
    
    /** Excerpt Length */
    $wp_customize->add_setting( 'serifi_excerpt_length', array(
            'default' => 35,
            'sanitize_callback' => 'serifi_sanitize_number_absint',
        ) 
    );
    
    $wp_customize->add_control( new Serifi_Slider_Control( 	$wp_customize,	'serifi_excerpt_length', array(
				'section' => 'serifi_blog_options',
				'priority' => 3,
				'label' => esc_html__( 'Excerpt Length', 'serifi' ),
				'description' => esc_html__( 'Automatically generated excerpt length (in words).', 'serifi' ),
                'choices' => array(
					'min' => 10,
					'max' => 100,
					'step' => 5,
				)                 
			)
		)
	);


	// Add Partial for Blog Layout and Excerpt Length.
	$wp_customize->selective_refresh->add_partial( 'serifi_blog_content_partial', array(
		'selector' => '.site-main',
		'settings' => array(
			'serifi_blog_layout',
			'serifi_blog_excerpt',
			'serifi_excerpt_length',
		),
		'render_callback'  => 'serifi_customize_partial_blog_content',
		'fallback_refresh' => false,
	) );
	
}
endif;

add_action( 'customize_register', 'serifi_customize_register_blog' );
