<?php
/**
 * Layout options
 * @package Serifi
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}


function serifi_customize_register_layout( $wp_customize ) {
    
    $wp_customize->add_section( 'serifi_layout_settings', array(
            'title'      => esc_html__( 'Layout Options', 'serifi' ),
            'priority'   => 21,
            'capability' => 'edit_theme_options',
        ) );
 
   // Header Layout
    $wp_customize->add_setting( 'serifi_header_layout', array(
		'default' => 'header1',
		'sanitize_callback' => 'serifi_sanitize_select',
    )
  );
  
  $wp_customize->add_control( new Serifi_Select_Control(	
	$wp_customize,	'serifi_header_layout', array(
		'label' => esc_html__( 'Header Layout', 'serifi' ),
		'priority'   => 11,
		'section' => 'serifi_layout_settings',
		'choices' => serifi_header_layout_options()),
	)
  );
  
   // Blog Layout
    $wp_customize->add_setting( 'serifi_blog_layout', array(
		'default' => 'classic-right',
		'sanitize_callback' => 'serifi_sanitize_select',
    )
  );
  
  $wp_customize->add_control( new Serifi_Select_Control(	
	$wp_customize,	'serifi_blog_layout', array(
		'label' => esc_html__( 'Blog Layout', 'serifi' ),
		'priority'   => 14,
		'section' => 'serifi_layout_settings',
		'choices' => serifi_blog_layout_options()),
	)
  );
 
   // Post Layout
    $wp_customize->add_setting( 'serifi_single_layout', array(
		'default' => 'classic-right',
		'sanitize_callback' => 'serifi_sanitize_select',
    )
  );
  
  $wp_customize->add_control( new Serifi_Select_Control(	
	$wp_customize,	'serifi_single_layout', array(
		'label'   => esc_html__( 'Post Style', 'serifi' ),
		'section' => 'serifi_layout_settings',
		'priority'   => 16,
		'choices' => serifi_post_layout_options()),
	)
  );


	// Add Partial for single Layout
	$wp_customize->selective_refresh->add_partial( 'serifi_customize_partial_single_post', array(
		'selector'         => '.site-content',
		'settings'         => array(
			'serifi_single_layout',
			),
		'render_callback'  => 'serifi_customize_partial_single_content',
		'fallback_refresh' => false,
	) );
	
	
	
	
}
add_action( 'customize_register', 'serifi_customize_register_layout' );


// Render the blog content for the selective refresh partial.
function serifi_customize_partial_blog_content() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/content', get_post_format() );
	}
}

// Render single posts partial
function serifi_customize_partial_single_post() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/content', 'single' );
	}
}