<?php

/**
 * Theme Customizer
 * @package Serifi
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

function serifi_customize_register($wp_customize)
{

	/** Add postMessage support for site title and description */
	$wp_customize->get_setting('blogname')->transport         = 'postMessage';
	$wp_customize->get_setting('blogdescription')->transport  = 'postMessage';
	$wp_customize->get_setting('background_color')->transport = 'refresh';
	$wp_customize->get_setting('background_image')->transport = 'refresh';


	// Show site title
	$wp_customize->add_setting('serifi_show_site_title',	array(
		'default' => true,
		'transport'  => 'postMessage',
		'sanitize_callback' => 'serifi_sanitize_checkbox',
	));

	$wp_customize->add_control(new Serifi_Toggle_Control(
		$wp_customize,
		'serifi_show_site_title',
		array(
			'label'    => esc_html__('Show the Site Title', 'serifi'),
			'description' => esc_html__('Show or hide the site title.', 'serifi'),
			'section'  => 'title_tagline',
		)
	));

	// Show site description
	$wp_customize->add_setting('serifi_show_site_desc',	array(
		'default' => true,
		'transport'  => 'postMessage',
		'sanitize_callback' => 'serifi_sanitize_checkbox',
	));

	$wp_customize->add_control(new Serifi_Toggle_Control(
		$wp_customize,
		'serifi_show_site_desc',
		array(
			'label'    => esc_html__('Show the Site Description', 'serifi'),
			'description' => esc_html__('Show or hide the site tagline [description].', 'serifi'),
			'section'  => 'title_tagline',
		)
	));

	// Site title colour
	$wp_customize->add_setting('serifi_header_title_colour', array(
		'default'           => '#333',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	));

	$wp_customize->add_control(new WP_Customize_Color_Control(
		$wp_customize,
		'serifi_header_title_colour',
		array(
			'label'       => esc_html__('Site Title Colour', 'serifi'),
			'description' => esc_html__('Sets the site title colour in the header area.', 'serifi'),
			'section'     => 'title_tagline',
		)
	));

	// Site tagline colour
	$wp_customize->add_setting('serifi_tagline_colour', array(
		'default'           => '#777',
		'transport' => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color'
	));

	$wp_customize->add_control(new WP_Customize_Color_Control(
		$wp_customize,
		'serifi_tagline_colour',
		array(
			'label'       => esc_html__('Site Tagline Colour', 'serifi'),
			'description' => esc_html__('Sets the site tagline [ description ] colour in the header area.', 'serifi'),
			'section'     => 'title_tagline',
		)
	));


	// Site Title Font Size for the custom header image
	$wp_customize->add_setting('site_title_font_size', array(
		'default'           => 1,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'serifi_sanitize_number_decimal',
	));

	$wp_customize->add_control(
		new Serifi_Slider_Control($wp_customize, 'site_title_font_size', array(
			'section'	  => 'title_tagline',
			'label'		  => esc_html__('Site Title Font Size', 'serifi'),
			'description' => esc_html__('Change the font size of your site title for the Custom Header Image.', 'serifi'),
			'priority'    => 65,
			'choices'	  => array(
				'min' 	=> 1,
				'max' 	=> 10,
				'step'	=> 0.25,
			)
		))
	);

}
add_action('customize_register', 'serifi_customize_register');
