<?php
/**
 * Theme Customizer main file
 * @package Serifi
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
		
// Get the theme customizer panels & sections
$serifi_panels = array( 'upgrade', 'site', 'layout', 'blog', 'header', 'page', 'post', 'color', 'typography', 'other', 'labels' );

foreach( $serifi_panels as $panel ){
    require get_template_directory() . '/inc/customizer/customizer-sections/' . $panel . '.php';
}

// Sanitization Functions
require get_template_directory() . '/inc/customizer/sanitization-functions.php';


// Add customizer stylesheet to the admin
function serifi_customizer_styles() {
  wp_enqueue_style( 'admin-style', get_stylesheet_directory_uri() . '/assets/css/customizer.css' );
}
add_action( 'admin_enqueue_scripts', 'serifi_customizer_styles');


// Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
function serifi_customize_preview_js() {
	wp_enqueue_script( 'serifi-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), null, true );
}
add_action( 'customize_preview_init', 'serifi_customize_preview_js' );

/* CUSTOMIZER PRESET CHOICES
	Set our colour preset options in the dropdown field
   ====================================================*/ 
function serifi_colour_preset_options() {
	return apply_filters( 'serifi_colour_preset_options', array (			
			'preset1' => get_template_directory_uri() . '/assets/images/preset1.png',
			'preset2' => get_template_directory_uri() . '/assets/images/preset2.png',
			'preset3'  => get_template_directory_uri() . '/assets/images/preset3.png',	
			'preset4'  => get_template_directory_uri() . '/assets/images/preset4.png',
			'preset5'  => get_template_directory_uri() . '/assets/images/preset5.png',
			'preset6'  => get_template_directory_uri() . '/assets/images/preset6.png',
	));
}

/* CUSTOMIZER HEADER CHOICES
	Set our header layout options in the dropdown field
   ====================================================*/ 
function serifi_header_layout_options() {
	return apply_filters( 'serifi_header_layout_options', array (
			'header1' => esc_html__( 'Logo Left Nav Right', 'serifi' ),
			'header2'  => esc_html__( 'Logo Center Nav Below', 'serifi' ),
			'header3' => esc_html__( 'Centered Outside', 'serifi' ),
	));
}


/* CUSTOMIZER BLOG CHOICES
	Set our blog layout options in the dropdown field
   ====================================================*/ 
function serifi_blog_layout_options() {
	return apply_filters( 'serifi_blog_layout_options', array (
			'classic-right' => esc_html__( 'Classic Right Sidebar', 'serifi' ),
			'classic-left'  => esc_html__( 'Classic Left Sidebar', 'serifi' ),
			'center' => esc_html__( 'Centered', 'serifi' ),
	));
}

/* CUSTOMIZER POST LAYOUT
	Set our full post layout options
   ====================================================*/
function serifi_post_layout_options() {
	return apply_filters( 'serifi_post_layout_options', array (
			'classic-right' => esc_html__( 'Classic Right Sidebar', 'serifi' ),
			'classic-left' => esc_html__( 'Classic Left Sidebar', 'serifi' ),
            'center' => esc_html__( 'Centered - No Sidebars', 'serifi' ),
	));
}
 